# LCN Frontend

This repository contains the frontend files for the Home Assistant LCN configuration panel.

## Features

- Device Configuration
  ![Device Configuration](./screenshots/lcn_devices.png?raw=true)

  - Set up modules and groups for all your LCN integrations.
  - Search for modules and groups and have them added automatically.
  - Select a module or group to access the respective Entity Configuration panel.

- Entity Configuration
  ![Entity Configuration](./screenshots/lcn_create_entity.png?raw=true)
  - Set up Home Assistant entities for each module or group.
  - Create new entities that map the functions of your LCN modules and configure their parameters.
  - New entities are automatically added to your Home Assistant configuration and you can add them to your dashboards just like for any other integration.
